@@ -159,7 +159,8 @@ def motionCorrect(
     fixed, fixed_vox, moving_vox,
     write_path, dataset_path=None,
     distributed_state=None, sigma=7,
-    transforms_dir=None
+    transforms_dir=None,
+    **kwargs,
 ):
     """
     """
@@ -168,13 +169,23 @@ def motionCorrect(
     ds = distributed_state
     if distributed_state is None:
         ds = csd.distributedState()
+        # writing large compressed chunks locks GIL for a long time
+        ds.modifyConfig({'distributed.comm.timeouts.connect':'60s',
+                         'distributed.comm.timeouts.tcp':'180s',}
+        )
         ds.initializeLSFCluster(job_extra=["-P scicompsoft"])
         ds.initializeClient()
 
     # create (lazy) dask bag from all frames
     frames = csio.daskBagOfFilePaths(folder, prefix, suffix)
     nframes = frames.npartitions
-    ds.scaleCluster(njobs=nframes)
+
+    # scale cluster carefully
+    if 'max_workers' in kwargs.keys():
+        max_workers = kwargs['max_workers']
+    else:
+        max_workers = 1250
+    ds.scaleCluster(njobs=min(nframes, max_workers))
 
     # align all
     dfixed = delayed(fixed)
